@@ -29,7 +29,6 @@
 #'
 #' @examples
 #' # LF method ----
-#' library(dplyr)
 #'
 #' # Example 1: given power and compute sample size
 #' x <- fixed_design_lf(
@@ -43,7 +42,7 @@
 #'   ),
 #'   study_duration = 36
 #' )
-#' x %>% summary()
+#' x |> summary()
 #'
 #' # Example 2: given sample size and compute power
 #' x <- fixed_design_lf(
@@ -57,7 +56,7 @@
 #'   ),
 #'   study_duration = 36
 #' )
-#' x %>% summary()
+#' x |> summary()
 #'
 fixed_design_lf <- function(
     alpha = 0.025,
@@ -100,52 +99,52 @@ fixed_design_lf <- function(
     }
   } else {
     warning("Lachin-Foulkes is not recommended for stratified designs!")
-    temp <- fail_rate %>%
-      group_by(stratum) %>%
+    temp <- fail_rate |>
+      group_by(stratum) |>
       summarize(n_duration = n())
     # calculate the S: duration of piecewise constant event rates
     if (all(temp$n_duration == 1)) {
       ss <- cbind(NULL, NULL)
     } else {
-      stratified_duration <- fail_rate %>%
-        select(stratum, duration) %>%
+      stratified_duration <- fail_rate |>
+        select(stratum, duration) |>
         tidyr::pivot_wider(names_from = stratum, values_from = duration, values_fn = list)
       ss <- do.call(cbind, lapply(stratified_duration, function(x) {
-        x %>% unlist()
-      })) %>%
+        x |> unlist()
+      })) |>
         as.matrix()
     }
     # calculate the lambdaC: event hazard rates for the control group
-    stratified_lambdac <- fail_rate %>%
-      select(stratum, fail_rate) %>%
+    stratified_lambdac <- fail_rate |>
+      select(stratum, fail_rate) |>
       tidyr::pivot_wider(names_from = stratum, values_from = fail_rate, values_fn = list)
     lambda_cc <- do.call(cbind, lapply(stratified_lambdac, function(x) {
-      x %>% unlist()
-    })) %>%
+      x |> unlist()
+    })) |>
       as.matrix()
     # calculate the eta: dropout hazard rates for the control group
-    stratified_eta <- fail_rate %>%
-      select(stratum, dropout_rate) %>%
+    stratified_eta <- fail_rate |>
+      select(stratum, dropout_rate) |>
       tidyr::pivot_wider(names_from = stratum, values_from = dropout_rate, values_fn = list)
     etaa <- do.call(cbind, lapply(stratified_eta, function(x) {
-      x %>% unlist()
-    })) %>%
+      x |> unlist()
+    })) |>
       as.matrix()
     # calculate the gamma: rates of entry by time period (rows) and strata (columns)
-    stratified_enroll_rate <- enroll_rate %>%
-      select(stratum, rate) %>%
+    stratified_enroll_rate <- enroll_rate |>
+      select(stratum, rate) |>
       tidyr::pivot_wider(names_from = stratum, values_from = rate, values_fn = list)
     gammaa <- do.call(cbind, lapply(stratified_enroll_rate, function(x) {
-      x %>% unlist()
-    })) %>%
+      x |> unlist()
+    })) |>
       as.matrix()
     # calculate the R: duration of time periods for recruitment rates specified in rows of gamma
-    stratified_enroll_duration <- enroll_rate %>%
-      select(stratum, duration) %>%
+    stratified_enroll_duration <- enroll_rate |>
+      select(stratum, duration) |>
       tidyr::pivot_wider(names_from = stratum, values_from = duration, values_fn = list)
     rr <- do.call(cbind, lapply(stratified_enroll_duration, function(x) {
-      x %>% unlist()
-    })) %>%
+      x |> unlist()
+    })) |>
       as.matrix()
   }
   # calculate the ahr as the hr in nSurv
@@ -184,7 +183,7 @@ fixed_design_lf <- function(
   )
   y <- list(
     input = input,
-    enroll_rate = enroll_rate %>% mutate(rate = rate * d$n / sum(enroll_rate$duration * enroll_rate$rate)),
+    enroll_rate = enroll_rate |> mutate(rate = rate * d$n / sum(enroll_rate$duration * enroll_rate$rate)),
     fail_rate = fail_rate,
     analysis = ans,
     design = "lf"
