@@ -61,7 +61,6 @@ to_integer <- function(x, ...) {
 #' @export
 #'
 #' @examples
-#' library(dplyr)
 #' library(gsDesign2)
 #'
 #' # Average hazard ratio
@@ -76,8 +75,8 @@ to_integer <- function(x, ...) {
 #'   ),
 #'   study_duration = 36
 #' )
-#' x %>%
-#'   to_integer() %>%
+#' x |>
+#'   to_integer() |>
 #'   summary()
 #'
 #' # FH
@@ -93,8 +92,8 @@ to_integer <- function(x, ...) {
 #'   rho = 0.5, gamma = 0.5,
 #'   study_duration = 36, ratio = 1
 #' )
-#' x %>%
-#'   to_integer() %>%
+#' x |>
+#'   to_integer() |>
 #'   summary()
 #'
 #' # MB
@@ -109,8 +108,8 @@ to_integer <- function(x, ...) {
 #'   tau = Inf, w_max = 2,
 #'   study_duration = 36, ratio = 1
 #' )
-#' x %>%
-#'   to_integer() %>%
+#' x |>
+#'   to_integer() |>
 #'   summary()
 #' }
 to_integer.fixed_design <- function(x, round_up_final = TRUE, ratio = x$input$ratio, ...) {
@@ -142,7 +141,7 @@ to_integer.fixed_design <- function(x, round_up_final = TRUE, ratio = x$input$ra
     }
   }
 
-  enroll_rate_new <- x$enroll_rate %>%
+  enroll_rate_new <- x$enroll_rate |>
     mutate(rate = rate * sample_size_new / output_n)
 
   # Round events
@@ -173,9 +172,10 @@ to_integer.fixed_design <- function(x, round_up_final = TRUE, ratio = x$input$ra
       n = x_new$analysis$n,
       event = x_new$analysis$event,
       time = x_new$analysis$time,
-      bound = (x_new$bound %>% filter(bound == "upper"))$z,
+      ahr = x_new$analysis$ahr,
+      bound = (x_new$bound |> filter(bound == "upper"))$z,
       alpha = x$input$alpha,
-      power = (x_new$bound %>% filter(bound == "upper"))$probability
+      power = (x_new$bound |> filter(bound == "upper"))$probability
     )
 
     ans <- list(
@@ -201,9 +201,10 @@ to_integer.fixed_design <- function(x, round_up_final = TRUE, ratio = x$input$ra
       n = x_new$analysis$n,
       event = x_new$analysis$event,
       time = x_new$analysis$time,
-      bound = (x_new$bound %>% filter(bound == "upper"))$z,
+      ahr = x_new$analysis$ahr,
+      bound = (x_new$bound |> filter(bound == "upper"))$z,
       alpha = x$input$alpha,
-      power = (x_new$bound %>% filter(bound == "upper"))$probability
+      power = (x_new$bound |> filter(bound == "upper"))$probability
     )
 
     ans <- list(
@@ -229,9 +230,10 @@ to_integer.fixed_design <- function(x, round_up_final = TRUE, ratio = x$input$ra
       n = x_new$analysis$n,
       event = x_new$analysis$event,
       time = x_new$analysis$time,
-      bound = (x_new$bound %>% filter(bound == "upper"))$z,
+      ahr = x_new$analysis$ahr,
+      bound = (x_new$bound |> filter(bound == "upper"))$z,
       alpha = x$input$alpha,
-      power = (x_new$bound %>% filter(bound == "upper"))$probability
+      power = (x_new$bound |> filter(bound == "upper"))$probability
     )
 
     ans <- list(
@@ -273,8 +275,8 @@ to_integer.fixed_design <- function(x, round_up_final = TRUE, ratio = x$input$ra
 #'   upar = list(sf = gsDesign::sfLDOF, total_spend = 0.025, param = NULL),
 #'   lower = gs_b,
 #'   lpar = c(-Inf, -Inf)
-#' ) %>%
-#'   to_integer() %>%
+#' ) |>
+#'   to_integer() |>
 #'   summary()
 #'
 #' gs_design_wlr(
@@ -283,8 +285,8 @@ to_integer.fixed_design <- function(x, round_up_final = TRUE, ratio = x$input$ra
 #'   upar = list(sf = gsDesign::sfLDOF, total_spend = 0.025, param = NULL),
 #'   lower = gs_b,
 #'   lpar = c(-Inf, -Inf)
-#' ) %>%
-#'   to_integer() %>%
+#' ) |>
+#'   to_integer() |>
 #'   summary()
 #'
 #' gs_design_rd(
@@ -297,8 +299,8 @@ to_integer.fixed_design <- function(x, round_up_final = TRUE, ratio = x$input$ra
 #'   upar = list(sf = gsDesign::sfLDOF, total_spend = 0.025, param = NULL),
 #'   lower = gs_b,
 #'   lpar = c(-Inf, -Inf)
-#' ) %>%
-#'   to_integer() %>%
+#' ) |>
+#'   to_integer() |>
 #'   summary()
 #'
 #' # Example 2: Calendar based spending
@@ -311,7 +313,7 @@ to_integer.fixed_design <- function(x, round_up_final = TRUE, ratio = x$input$ra
 #'   ),
 #'   lower = gs_b,
 #'   lpar = c(-Inf, -Inf)
-#' ) %>% to_integer()
+#' ) |> to_integer()
 #'
 #' # The IA nominal p-value is the same as the IA alpha spending
 #' x$bound$`nominal p`[1]
@@ -382,7 +384,7 @@ to_integer.gs_design <- function(x, round_up_final = TRUE, ratio = x$input$ratio
     sample_size_new <- as.integer(sample_size_new)
 
     enroll_rate <- x$enroll_rate
-    enroll_rate_new <- enroll_rate %>%
+    enroll_rate_new <- enroll_rate |>
       mutate(rate = rate * sample_size_new / x$analysis$n[n_analysis])
 
     # Updated upar
@@ -494,14 +496,14 @@ to_integer.gs_design <- function(x, round_up_final = TRUE, ratio = x$input$ratio
         stratum = rep(x$input$p_c$stratum, n_analysis)
       )
       tbl_n <- if (n_stratum == 1) {
-        tbl_n %>%
+        tbl_n |>
           left_join(sample_size_new)
       } else {
-        tbl_n %>%
-          left_join(x$input$stratum_prev) %>%
-          left_join(sample_size_new) %>%
-          mutate(n_new = prevalence * n) %>%
-          select(-c(n, prevalence)) %>%
+        tbl_n |>
+          left_join(x$input$stratum_prev) |>
+          left_join(sample_size_new) |>
+          mutate(n_new = prevalence * n) |>
+          select(-c(n, prevalence)) |>
           rename(n = n_new)
       }
     })
