@@ -1,6 +1,4 @@
 library(testthat)
-library(gsDesign)
 library(gsDesign2)
-library(dplyr)
 
 test_check("gsDesign2")
