@@ -21,27 +21,27 @@ test_that("compare results with AHR in the situation of single analysis", {
   )
 
   expect_equal(
-    out$analysis %>% dplyr::select(time, ahr) %>% as.data.frame(),
+    out$analysis |> dplyr::select(time, ahr) |> as.data.frame(),
     ahr(
       enroll_rate = enroll_rate,
       fail_rate = fail_rate,
       total_duration = total_duration
-    ) %>%
-      dplyr::select(time, ahr) %>%
+    ) |>
+      dplyr::select(time, ahr) |>
       as.data.frame()
   )
 
   # update enroll_rate for AHR to make Events/info/info0 also match in outputs
-  enroll_rate1 <- enroll_rate %>% dplyr::mutate(rate = rate * c(out$analysis$n / (duration %*% rate)))
+  enroll_rate1 <- enroll_rate |> dplyr::mutate(rate = rate * c(out$analysis$n / (duration %*% rate)))
 
   expect_equal(
-    out$analysis %>% dplyr::select(time, ahr, event, info, info0) %>% as.data.frame(),
+    out$analysis |> dplyr::select(time, ahr, event, info, info0) |> as.data.frame(),
     ahr(
       enroll_rate = enroll_rate1,
       fail_rate = fail_rate,
       total_duration = total_duration
-    ) %>%
-      dplyr::select(time, ahr, event, info, info0) %>%
+    ) |>
+      dplyr::select(time, ahr, event, info, info0) |>
       as.data.frame()
   )
 })
@@ -67,33 +67,33 @@ test_that("compare results with gsDesign2::AHR in the situation with IF and mult
   )
 
   expect_equal(
-    out$analysis %>%
-      dplyr::select(time, ahr) %>%
-      dplyr::distinct(.keep_all = TRUE) %>%
+    out$analysis |>
+      dplyr::select(time, ahr) |>
+      dplyr::distinct(.keep_all = TRUE) |>
       as.data.frame(),
     ahr(
       enroll_rate = enroll_rate,
       fail_rate = fail_rate,
       total_duration = total_duration
-    ) %>%
-      dplyr::select(time, ahr) %>%
+    ) |>
+      dplyr::select(time, ahr) |>
       as.data.frame()
   )
 
   # update enroll_rate for AHR to make Events/info/info0 also match in outputs
-  enroll_rate1 <- enroll_rate %>% dplyr::mutate(rate = rate * c(max(out$analysis$n) / (duration %*% rate)))
+  enroll_rate1 <- enroll_rate |> dplyr::mutate(rate = rate * c(max(out$analysis$n) / (duration %*% rate)))
 
   expect_equal(
-    out$analysis %>%
-      dplyr::select(time, ahr, event, info, info0) %>%
-      dplyr::distinct(.keep_all = TRUE) %>%
+    out$analysis |>
+      dplyr::select(time, ahr, event, info, info0) |>
+      dplyr::distinct(.keep_all = TRUE) |>
       as.data.frame(),
     ahr(
       enroll_rate = enroll_rate1,
       fail_rate = fail_rate,
       total_duration = total_duration
-    ) %>%
-      dplyr::select(time, ahr, event, info, info0) %>%
+    ) |>
+      dplyr::select(time, ahr, event, info, info0) |>
       as.data.frame()
   )
 })
