@@ -1,20 +1,20 @@
 test_that("given sample size, the output power arrives at the target", {
   # set enrollment rates
-  enroll_rate <- tibble::tibble(stratum = "All", duration = 12, rate = 500 / 12)
+  enroll_rate <- define_enroll_rate(duration = 12, rate = 500 / 12)
 
   # set failure rates
-  fail_rate <- tibble::tibble(
-    stratum = "All",
+  fail_rate <- define_fail_rate(
     duration = c(4, 100),
     fail_rate = log(2) / 15, # median survival 15 month
-    hr = c(1, .6),
-    dropout_rate = 0.001
+    dropout_rate = 0.001,
+    hr = c(1, .6)
   )
 
   # output from gsDesign2
   x1 <- gsDesign2:::fixed_design_size_rmst(enroll_rate, fail_rate,
-                                           ratio = 1, analysis_time = 36,
-                                           alpha = 0.025, test = "rmst_difference")
+    ratio = 1, analysis_time = 36,
+    alpha = 0.025, test = "rmst_difference"
+  )
 
   # output from npsurvSS
   gs_arm <- gs_create_arm(enroll_rate, fail_rate, ratio = 1, total_time = 36)
@@ -30,7 +30,6 @@ test_that("given sample size, the output power arrives at the target", {
   expect_equal(x1$bound$probability, x2)
 })
 
-
 test_that("given power, the output sample size arrives at the target power", {
   # set enrollment rates
   enroll_rate <- tibble::tibble(stratum = "All", duration = 12, rate = 500 / 12)
@@ -46,8 +45,9 @@ test_that("given power, the output sample size arrives at the target power", {
 
   # output from gsDesign2
   x1 <- fixed_design_power_rmst(enroll_rate, fail_rate,
-                                analysis_time = 36,
-                                test = "rmst_difference")
+    analysis_time = 36,
+    test = "rmst_difference"
+  )
 
   # output from npsurvSS
   gs_arm <- gs_create_arm(enroll_rate, fail_rate, ratio = 1, total_time = 36)
